@@ -1012,16 +1012,25 @@ class TestINSPIRE2CDSGeneric(unittest.TestCase):
 
     def test_article_to_publication(self):
         """Test 542__e -> 542__3 Article is converted to Publication."""
-        from harvestingkit.bibrecord import record_get_field_values
+        from harvestingkit.bibrecord import field_get_subfield_instances,\
+            record_get_field_values, record_get_field_instances
         from harvestingkit.inspire_cds_package.from_inspire import Inspire2CDS
 
         xml = """
         <collection>
             <record>
+                <datafield tag="542" ind1=" " ind2=" ">
+                    <subfield code="g">Another Field</subfield>
+                    <subfield code="e">Not Article</subfield>
+                    <subfield code="a">Another Field</subfield>
+                </datafield>
                 <datafield tag="542" ind1=" " ind2=" ">
                     <subfield code="a">Another Field</subfield>
                     <subfield code="e">Article</subfield>
                 </datafield>
+                <datafield tag="542" ind1=" " ind2=" ">
+                    <subfield code="a">Only `a` subfield</subfield>
+                </datafield>
             </record>
             <record>
                 <datafield tag="542" ind1=" " ind2=" ">
@@ -1033,14 +1042,28 @@ class TestINSPIRE2CDSGeneric(unittest.TestCase):
         rec1, rec2 = Inspire2CDS.from_source(xml)
 
         converted_rec1 = rec1.get_record()
-        rec1_3_value = record_get_field_values(converted_rec1, tag="542", code="3")
-        self.assertEqual(rec1_3_value, ["publication"])
-        rec1_a_value = record_get_field_values(converted_rec1, tag="542", code="a")
-        self.assertEqual(rec1_a_value, ["Another Field"])
+
+        rec1_542_fields = record_get_field_instances(converted_rec1, '542')
+        rec1_542_0_subs = field_get_subfield_instances(rec1_542_fields[0])
+        self.assertEqual(
+            rec1_542_0_subs,
+            [('g', 'Another Field'), ('3', 'Not Article'), ('a', 'Another Field')])
+
+        rec1_542_1_subs = field_get_subfield_instances(rec1_542_fields[1])
+        self.assertEqual(
+            rec1_542_1_subs, [('a', 'Another Field'), ('3', 'publication')])
+
+        rec1_542_2_subs = field_get_subfield_instances(rec1_542_fields[2])
+        self.assertEqual(
+            rec1_542_2_subs, [('a', 'Only `a` subfield')])
 
         converted_rec2 = rec2.get_record()
-        rec2_value = record_get_field_values(converted_rec2, tag="542", code="3")
-        self.assertEqual(rec2_value, ["AnotherValue"])
+
+        rec2_542_fields = record_get_field_instances(converted_rec2, '542')
+        rec2_542_0_subs = field_get_subfield_instances(rec2_542_fields[0])
+        self.assertEqual(
+            rec2_542_0_subs, [('3', 'AnotherValue')])
+
 
     def test_article_773(self):
         """Test if tag 773 has c,p,v,y then doc_type is ARTICLE."""
